package Hops;

use strict;
use Catalyst qw/-Debug Static FormValidator FillInForm Session::FastMmap/;
use YAML;
our $VERSION = '0.05';

Hops->config( YAML::LoadFile('/home/simonf/devel/Catalyst/Hops/hops.yml') );

Hops->setup;

sub default : Private {
    my ( $self, $c, $class, $method ) = @_;
    shift @{ $c->req->args } if $class;
    $class = 'beer' unless $class;

    $method = $c->req->args->[0] = 'list' unless $method;

    $c->stash->{display_name} = $class;

    my $loader = $c->comp('Hops::M::CDBI')->loader;
    my $model  = $loader->find_class($class);
    $c->stash->{class} = $model;

    if ( $method eq 'list' ) {
        $c->stash->{display_tables} = Hops->config->{display_tables};
    }

    $c->form( optional => [ $model->columns ] );
    $c->forward('Hops::C::CRUD');
}

sub static_css : Regex('\.css$') {
    my ( $self, $c ) = @_;
    $c->serve_static('text/css');
}

sub end : Private {
    my ( $self, $c ) = @_;
    my $handled = $c->res->output || $c->res->redirect;
    $c->stash->{app} = $self;
    $c->forward('Hops::V::TT') unless $handled;
}

=head1 NAME

Hops - A sample Catalyst application

=head1 SYNOPSIS

    Demonstrates basic Create/Retrieve/Update/Delete operations
	 on arbitrary classes.
     
    Defines the logic to do a requested operation on a requested class,
    eg, translates '/hops/beer/view/1' into a request to view the row
    in the 'beer' table with id 1.     

=head1 DESCRIPTION

Rewrite of BeerDB, a Maypole example

=head1 AUTHOR

Simon Ilyushchenko, simonf@simonf.com

=head1 LICENSE

This library is free software . You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;

