package Hops::C::CRUD;

use strict;
use base 'Catalyst::Base';

sub do_add {
    my ( $self, $c ) = @_;
    $c->stash->{class}->create_from_form( $c->form );
    my $class = $c->stash->{display_name};
    $c->res->redirect( $c->req->base . "/" . $class . "/list" );
}

sub do_edit {
    my ( $self, $c ) = @_;
    $c->stash->{item}->update_from_form( $c->form );
    my $class = $c->stash->{display_name};
    my $id    = $c->stash->{item}->id;
    $c->res->redirect(
        $c->req->base . $class . "/view/" . $id );
}

sub destroy {
    my ( $self, $c ) = @_;
    $c->stash->{item}->delete;
    my $class = $c->stash->{display_name};
    $c->res->redirect( $c->req->base . $class . "/list" );
}

sub list {
    my ( $self, $c ) = @_;

    my $class = $c->stash->{class};

    # paginate the list
    my $pager = $class->pager;
    $pager->per_page(2);
    $pager->page( $c->req->params->{page} || 1 );
    $pager->where( { name => { '!=', undef } } );

    my $order = $c->req->params->{order};
    if ($order) {
        $order .= " desc"
          if lc( $c->req->params->{o2} ) eq "desc";

        #$model->retrieve_all_sort_field($order);
        $pager->order_by($order);
    }

    # you're forced to set a where clause even if returning all data...
    $c->stash->{all_objects} = [ $pager->search_where ];
    $c->stash->{pager}       = $pager;
}

sub process {
    my $self   = shift;
    my $c      = shift;
    my $method = shift || 'list';

    my $class = $c->stash->{class};
    $c->stash->{item} = $class->retrieve( $_[0] ) if $_[0];
    $c->stash->{template} = $method;
    my $item = $c->stash->{item};
    $self->$method( $c, @_ ) if $self->can($method);
}

=head1 NAME

Hops::C::CRUD - A Component

=head1 SYNOPSIS

=head1 DESCRIPTION

Performs CRUD operations on the database.

=head1 AUTHOR

Simon Ilyushchenko, simonf@simonf.com

=head1 LICENSE

This library is free software . You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;

