package Hops::M::CDBI;

use strict;
use base 'Catalyst::Model::CDBI';

use Class::DBI::Loader::Relationship;

use Class::DBI::AsForm;
use Class::DBI::FromForm;
use Class::DBI::Plugin::RetrieveAll;

__PACKAGE__->config(
    dsn                => Hops->config->{dsn},
    user               => Hops->config->{user},
    password           => Hops->config->{password},
    additional_classes => [
        qw/Class::DBI::Plugin::RetrieveAll Class::DBI::Plugin::AbstractCount Class::DBI::Plugin::Pager/
    ],
);

sub new {
    my $class = shift;
    my $self  = $class->NEXT::new(@_);

    $self->loader->relationship($_) for (
        "a brewery produces beers",
        "a style defines beers",
        "a pub has beers on handpumps"
    );

    $self->loader->find_class('brewery')->columns( Stringify => qw/name/ );
    $self->loader->find_class('style')->columns( Stringify   => qw/name/ );

    return $self;
}

=head1 NAME

Hops::M::CDBI - CDBI Model Component

=head1 SYNOPSIS

    Base class for BeerDB models

=head1 DESCRIPTION

Rewrite of BeerDB, a Maypole example

=head1 AUTHOR

Simon Ilyushchenko, simonf@simonf.com

=head1 LICENSE

This library is free software . You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;

